@@ -13,19 +13,19 @@ pd.options.display.max_columns = 10
 ##############################################
 ### Parameters
 
-remote = {'bucket': 'fire-emergency-nz', 'connection_config': 'https://b2.tethys-ts.xyz'}
+remote = {'bucket': 'ecan-env-monitoring', 'connection_config': 'https://b2.tethys-ts.xyz'}
 
-dataset_id = 'dddb02cd5cb7ae191311ab19'
-station_id = 'fedeb59e6c7f47597a7d47c7'
-station_ids = [station_id, 'fe9a63fae6f7fe58474bb3c0']
+dataset_id = 'b5d84aa773de2a747079c127'
+station_id = '4db28a9db0cb036507490887'
+station_ids = [station_id, '474f75b4de127caca088620a']
 
 outputs = ['Dataset', 'DataArray', 'Dict']
 
-geometry1 = {'type': 'Point', 'coordinates': [171.05, -43.1]}
+geometry1 = {'type': 'Point', 'coordinates': [172, -42.8]}
 # geometry2 = shape(geometry1).buffer(0.5)
-lat = -43.1
-lon = 171.05
-distance = 0.5
+lat = -42.8
+lon = 172.0
+distance = 0.2
 
 ######################################
 ### Testing
@@ -44,7 +44,7 @@ t1 = Tethys([remote])
 def test_get_stations():
     stn_list1 = t1.get_stations(dataset_id)
 
-    assert len(stn_list1) > 200
+    assert len(stn_list1) > 2
 
 
 ## Get the stations loaded in the object
@@ -59,20 +59,20 @@ def test_get_run_dates():
 
 @pytest.mark.parametrize('output', outputs)
 def test_get_results(output):
-    data1 = t1.get_results(dataset_id, station_id, remove_height=True, output=output)
+    data1 = t1.get_results(dataset_id, station_id, squeeze_dims=True, output=output)
 
     if output == 'Dataset':
-        assert len(data1.time) > 1000
+        assert len(data1.time) > 90
     elif output == 'DataArray':
-        assert len(data1.time) > 1000
+        assert len(data1.time) > 90
     elif output == 'Dict':
-        assert len(data1['coords']['time']['data']) > 1000
+        assert len(data1['coords']['time']['data']) > 90
     else:
         raise ValueError('Forgot to put in new assertion')
 
 
 def test_get_bulk_results():
-    data2 = t1.get_bulk_results(dataset_id, station_ids, remove_height=True, output='Dataset')
+    data2 = t1.get_bulk_results(dataset_id, station_ids, squeeze_dims=True, output='Dataset')
 
     assert len(data2) > 6
 
@@ -92,7 +92,7 @@ def test_get_nearest_station2():
 def test_get_intersection_stations1():
     s3 = t1.get_stations(dataset_id, lat=lat, lon=lon, distance=distance)
 
-    assert len(s3) >= 3
+    assert len(s3) >= 2
 
 
 def test_get_nearest_results1():
